extern crate core;

mod client;
mod config;
mod handles;
mod typing;
mod utils;
mod events;

use crate::events::handle_events;
use client::handle_client;
use config::config::STATIC_ADDR as addr;
use tokio::net::TcpListener;
use tokio::sync::mpsc;

#[tokio::main]
async fn main() {
    let listener = TcpListener::bind(addr).await.unwrap();
    // 创建事件通道
    let (event_sender, event_receiver) = mpsc::unbounded_channel();
    // 启动事件处理任务
    tokio::spawn(handle_events(event_receiver));
    while let Ok((stream, _)) = listener.accept().await {
        let client_event_sender = event_sender.clone();
        // 创建一个用于事件中心向客户端发送消息的通道
        let (center_to_client_sender, center_to_client_receiver) = mpsc::channel(10);
        tokio::spawn(handle_client(stream, client_event_sender, center_to_client_sender, center_to_client_receiver));
    }
}